#!/bin/sh -efu

. shell-error
a= . install2-init-functions

# [ "$(stat -f -c %i $destdir)" != "$(stat -f -c %i $destdir/srv)" ] || exit 0

public='/srv/public'
shared='/srv/share'
nfsconf='/etc/sysconfig/nfs'
smbconf='/etc/samba/smb.conf'
servicedir='/etc/avahi/services'
vsftpcf='/etc/vsftpd/conf'
vsftpxi='/etc/xinetd.d/vsftpd'

mkdir -p "$destdir$public"
mkdir -p -m 1777 "$destdir$shared"

# nfs things
printf -- '%s -ro,insecure,no_subtree_check,fsid=1 *\n' "$public" > "$destdir/etc/exports"
printf -- '#%s -rw,insecure,fsid=0,sec=krb5 *\n' "$shared" >> "$destdir/etc/exports"
#[ ! -f "$destdir$nfsconf" ] || sed -i 's/^.\+SECURE_NFS.\+$/SECURE_NFS=yes/' "$destdir$nfsconf"

# ftp ones
if [ -f "$destdir$vsftpxi" ]; then
sed -i \
    -e '/^[[:blank:]]\+disable/ s/=.\+$/= no/' \
    -e '/only_from/d' \
    -e '/server_args/a\
	only_from	= 0/0' "$destdir$vsftpxi"
fi

if [ -d "$destdir/var/ftp" ]; then
	echo "/var$public      /var/ftp    bind    bind    0       0" >> $destdir/etc/fstab
else
	ln -s "..$public" "$destdir/var/ftp"
fi

# avahi service declarations
if [ -d "$destdir$servicedir" ]; then
cat > "$destdir$servicedir/mirror.service" <<E_O_F
<service-group>
  <name replace-wildcards="no">mirror</name>
  <service>
    <type>_nfs._tcp</type>
    <port>2049</port>
    <txt-record>path=$public/mirror</txt-record>
    <txt-record>sec=sys</txt-record>
    <txt-record>options=hard,intr,nolock,ro</txt-record>
  </service>
</service-group>
E_O_F

[ ! -f "$destdir$smbconf" ] || cat > "$destdir$servicedir/samba.service" <<E_O_F
<service-group>
  <name replace-wildcards="yes">%h</name>
  <service>
    <type>_smb._tcp</type>
    <port>445</port>
    <txt-record>path=share</txt-record>
    <txt-record>logon_mount=yes</txt-record>
  </service>
</service-group>
E_O_F

cat > "$destdir$servicedir/anonftp.service" <<E_O_F
<service-group>
  <name replace-wildcards="yes">%h</name>
  <service>
    <type>_ftp._tcp</type>
    <port>21</port>
  </service>
</service-group>
E_O_F

fi

# services
if [ -e "$destdir/etc/rc.d/init.d/rpcbind" ]; then
	exec_chroot control rpcbind server
	exec_chroot chkconfig rpcbind on
fi
[ -e "$destdir/etc/rc.d/init.d/nfslock" ] && exec_chroot chkconfig nfslock on ||:
[ -e "$destdir/etc/rc.d/init.d/smb" ]     && exec_chroot chkconfig smb on ||:

